This function calculates the position of a club in their respective division by summing the positions of the first n = counters and sorting the sum from smallest to largest.

get_division_results(raw_results, counters = 4)

Arguments

raw_results

the finishing positions of the runners

counters

the total number of counters to use for team results

Value