A single forward step of the forward filtering algorithm for a hidden Markov model

hmm_forward_step(alpha, y, observation, transition_matrix)

Arguments

alpha

The previous posterior distribution over the discrete states of the HMM

observation

the observation distribution

transition_matrix

the transition matrix

x0

the initial state distribution

Value