Update the value of epsilon during an adaptation phase
update_step_size( iteration, accept_prob, mu, delta = 0.65, k = 0.75, gamma = 0.05, t0 = 10 )
| iteration | the current iteration |
|---|---|
| accept_prob | the acceptance probability from the previous time step |
| mu | tuning parameter, default set to log(10 * eps0) |
| delta | target acceptance probability, default 0.65 |
| k | tuning parameter, default set to 0.75 |
| gamma | tuning parameter, default set to 0.05 |
| t0 | tuning parameter, default set to 10.0 |
| hm0 | the previous state |
| logeps0 | the previous state |
| logepsbar0 | the previous state |